from plantstar_shared.SysconType import SysconType


class DataCollectionModuleProcessNames(SysconType):
    PROCESS_SPAWNER = ("Process Spawner", )
    RAW_DATA_PROCESSOR_INTERFACE = ("Raw Data Processor Interface", )
    RTL_RIO_3 = ("RTL RIO 3", )
